@@ -1,11 +1,14 @@
 import boto3
 import json
-class Util:
-    @staticmethod
-    def get_secret_aws(env: str, logger):
-        secret_name = f"nu0051005-measurement-systems-{env}-mesysqcd-secretrds-cnx1"
-        region_name = "us-east-1"
 
+class Util:
+    """Utility class for common operations"""
+    
+    @staticmethod
+    def get_secret_aws(secret_name: str, logger, region_name: str):
+        """
+        Retrieves AWS Secrets Manager secret and returns database credentials
+        """
         try:
             session = boto3.session.Session()
             client = session.client(
@@ -31,9 +34,5 @@ class Util:
             msg = f"Error getting the secret '{secret_name}': {str(e)}"
             logger.error(msg)
             raise Exception(msg)
-        
-    @staticmethod
-    def show(env: str, logger):
-        print("Hola mundo")
-        print(f"Environment: {env}")
+
 
